@@ -1,3 +1,5 @@
+from __future__ import annotations
+
 import logging
 import platform
 import signal
@@ -5,7 +7,6 @@ import socket
 import sys
 from pathlib import Path
 from time import sleep
-from typing import List, Optional, Type
 
 import pytest
 
@@ -41,7 +42,7 @@ class TestBaseReload:
     def setup(
         self,
         reload_directory_structure: Path,
-        reloader_class: Optional[Type[BaseReload]],
+        reloader_class: type[BaseReload] | None,
     ):
         if reloader_class is None:  # pragma: no cover
             pytest.skip("Needed dependency not installed")
@@ -61,9 +62,7 @@ class TestBaseReload:
         reloader.startup()
         return reloader
 
-    def _reload_tester(
-        self, touch_soon, reloader: BaseReload, *files: Path
-    ) -> Optional[List[Path]]:
+    def _reload_tester(self, touch_soon, reloader: BaseReload, *files: Path) -> list[Path] | None:
         reloader.restart()
         if WatchFilesReload is not None and isinstance(reloader, WatchFilesReload):
             touch_soon(*files)
@@ -74,9 +73,7 @@ class TestBaseReload:
                 file.touch()
         return next(reloader)
 
-    @pytest.mark.parametrize(
-        "reloader_class", [StatReload, WatchGodReload, WatchFilesReload]
-    )
+    @pytest.mark.parametrize("reloader_class", [StatReload, WatchGodReload, WatchFilesReload])
     def test_reloader_should_initialize(self) -> None:
         """
         A basic sanity check.
@@ -89,9 +86,7 @@ class TestBaseReload:
             reloader = self._setup_reloader(config)
             reloader.shutdown()
 
-    @pytest.mark.parametrize(
-        "reloader_class", [StatReload, WatchGodReload, WatchFilesReload]
-    )
+    @pytest.mark.parametrize("reloader_class", [StatReload, WatchGodReload, WatchFilesReload])
     def test_reload_when_python_file_is_changed(self, touch_soon) -> None:
         file = self.reload_path / "main.py"
 
@@ -104,12 +99,8 @@ class TestBaseReload:
 
             reloader.shutdown()
 
-    @pytest.mark.parametrize(
-        "reloader_class", [StatReload, WatchGodReload, WatchFilesReload]
-    )
-    def test_should_reload_when_python_file_in_subdir_is_changed(
-        self, touch_soon
-    ) -> None:
+    @pytest.mark.parametrize("reloader_class", [StatReload, WatchGodReload, WatchFilesReload])
+    def test_should_reload_when_python_file_in_subdir_is_changed(self, touch_soon) -> None:
         file = self.reload_path / "app" / "sub" / "sub.py"
 
         with as_cwd(self.reload_path):
@@ -121,9 +112,7 @@ class TestBaseReload:
             reloader.shutdown()
 
     @pytest.mark.parametrize("reloader_class", [WatchFilesReload, WatchGodReload])
-    def test_should_not_reload_when_python_file_in_excluded_subdir_is_changed(
-        self, touch_soon
-    ) -> None:
+    def test_should_not_reload_when_python_file_in_excluded_subdir_is_changed(self, touch_soon) -> None:
         sub_dir = self.reload_path / "app" / "sub"
         sub_file = sub_dir / "sub.py"
 
@@ -139,18 +128,12 @@ class TestBaseReload:
 
             reloader.shutdown()
 
-    @pytest.mark.parametrize(
-        "reloader_class, result", [(StatReload, False), (WatchFilesReload, True)]
-    )
-    def test_reload_when_pattern_matched_file_is_changed(
-        self, result: bool, touch_soon
-    ) -> None:
+    @pytest.mark.parametrize("reloader_class, result", [(StatReload, False), (WatchFilesReload, True)])
+    def test_reload_when_pattern_matched_file_is_changed(self, result: bool, touch_soon) -> None:
         file = self.reload_path / "app" / "js" / "main.js"
 
         with as_cwd(self.reload_path):
-            config = Config(
-                app="tests.test_config:asgi_app", reload=True, reload_includes=["*.js"]
-            )
+            config = Config(app="tests.test_config:asgi_app", reload=True, reload_includes=["*.js"])
             reloader = self._setup_reloader(config)
 
             assert bool(self._reload_tester(touch_soon, reloader, file)) == result
@@ -164,9 +147,7 @@ class TestBaseReload:
             WatchGodReload,
         ],
     )
-    def test_should_not_reload_when_exclude_pattern_match_file_is_changed(
-        self, touch_soon
-    ) -> None:
+    def test_should_not_reload_when_exclude_pattern_match_file_is_changed(self, touch_soon) -> None:
         python_file = self.reload_path / "app" / "src" / "main.py"
         css_file = self.reload_path / "app" / "css" / "main.css"
         js_file = self.reload_path / "app" / "js" / "main.js"
@@ -186,9 +167,7 @@ class TestBaseReload:
 
             reloader.shutdown()
 
-    @pytest.mark.parametrize(
-        "reloader_class", [StatReload, WatchGodReload, WatchFilesReload]
-    )
+    @pytest.mark.parametrize("reloader_class", [StatReload, WatchGodReload, WatchFilesReload])
     def test_should_not_reload_when_dot_file_is_changed(self, touch_soon) -> None:
         file = self.reload_path / ".dotted"
 
@@ -200,9 +179,7 @@ class TestBaseReload:
 
             reloader.shutdown()
 
-    @pytest.mark.parametrize(
-        "reloader_class", [StatReload, WatchGodReload, WatchFilesReload]
-    )
+    @pytest.mark.parametrize("reloader_class", [StatReload, WatchGodReload, WatchFilesReload])
     def test_should_reload_when_directories_have_same_prefix(self, touch_soon) -> None:
         app_dir = self.reload_path / "app"
         app_file = app_dir / "src" / "main.py"
@@ -230,9 +207,7 @@ class TestBaseReload:
             pytest.param(WatchFilesReload, marks=skip_if_m1),
         ],
     )
-    def test_should_not_reload_when_only_subdirectory_is_watched(
-        self, touch_soon
-    ) -> None:
+    def test_should_not_reload_when_only_subdirectory_is_watched(self, touch_soon) -> None:
         app_dir = self.reload_path / "app"
         app_dir_file = self.reload_path / "app" / "src" / "main.py"
         root_file = self.reload_path / "main.py"
@@ -245,9 +220,7 @@ class TestBaseReload:
         reloader = self._setup_reloader(config)
 
         assert self._reload_tester(touch_soon, reloader, app_dir_file)
-        assert not self._reload_tester(
-            touch_soon, reloader, root_file, app_dir / "~ignored"
-        )
+        assert not self._reload_tester(touch_soon, reloader, root_file, app_dir / "~ignored")
 
         reloader.shutdown()
 
@@ -335,9 +308,7 @@ class TestBaseReload:
             reloader.shutdown()
 
     @pytest.mark.parametrize("reloader_class", [WatchGodReload])
-    def test_should_detect_new_reload_dirs(
-        self, touch_soon, caplog: pytest.LogCaptureFixture, tmp_path: Path
-    ) -> None:
+    def test_should_detect_new_reload_dirs(self, touch_soon, caplog: pytest.LogCaptureFixture, tmp_path: Path) -> None:
         app_dir = tmp_path / "app"
         app_file = app_dir / "file.py"
         app_dir.mkdir()
@@ -346,9 +317,7 @@ class TestBaseReload:
         app_first_file = app_first_dir / "file.py"
 
         with as_cwd(tmp_path):
-            config = Config(
-                app="tests.test_config:asgi_app", reload=True, reload_includes=["app*"]
-            )
+            config = Config(app="tests.test_config:asgi_app", reload=True, reload_includes=["app*"])
             reloader = self._setup_reloader(config)
             assert self._reload_tester(touch_soon, reloader, app_file)
 
