@@ -41,12 +41,11 @@ def test_cli_print_version() -> None:
 
     assert result.exit_code == 0
     assert (
-        "Running uvicorn %s with %s %s on %s"
-        % (
-            uvicorn.__version__,
-            platform.python_implementation(),
-            platform.python_version(),
-            platform.system(),
+        "Running uvicorn {version} with {py_implementation} {py_version} on {system}".format(  # noqa: UP032
+            version=uvicorn.__version__,
+            py_implementation=platform.python_implementation(),
+            py_version=platform.python_version(),
+            system=platform.system(),
         )
     ) in result.output
 
@@ -103,9 +102,7 @@ def test_cli_call_multiprocess_run() -> None:
 
 
 @pytest.fixture(params=(True, False))
-def uds_file(
-    tmp_path: Path, request: pytest.FixtureRequest
-) -> Path:  # pragma: py-win32
+def uds_file(tmp_path: Path, request: pytest.FixtureRequest) -> Path:  # pragma: py-win32
     file = tmp_path / "uvicorn.sock"
     should_create_file = request.param
     if should_create_file:
@@ -119,9 +116,7 @@ def test_cli_uds(uds_file: Path) -> None:  # pragma: py-win32
 
     with mock.patch.object(Config, "bind_socket") as mock_bind_socket:
         with mock.patch.object(Multiprocess, "run") as mock_run:
-            result = runner.invoke(
-                cli, ["tests.test_cli:App", "--workers=2", "--uds", str(uds_file)]
-            )
+            result = runner.invoke(cli, ["tests.test_cli:App", "--workers=2", "--uds", str(uds_file)])
 
     assert result.exit_code == 0
     assert result.output == ""
@@ -136,8 +131,7 @@ def test_cli_incomplete_app_parameter() -> None:
     result = runner.invoke(cli, ["tests.test_cli"])
 
     assert (
-        'Error loading ASGI app. Import string "tests.test_cli" '
-        'must be in format "<module>:<attribute>".'
+        'Error loading ASGI app. Import string "tests.test_cli" ' 'must be in format "<module>:<attribute>".'
     ) in result.output
     assert result.exit_code == 1
 
