@@ -1,3 +1,7 @@
+from __future__ import annotations
+
+import configparser
+import io
 import json
 import logging
 import os
@@ -5,7 +9,7 @@ import socket
 import sys
 import typing
 from pathlib import Path
-from typing import Literal, Optional
+from typing import Any, Literal
 from unittest.mock import MagicMock
 
 import pytest
@@ -42,9 +46,7 @@ def yaml_logging_config(logging_config: dict) -> str:
     return yaml.dump(logging_config)
 
 
-async def asgi_app(
-    scope: "Scope", receive: "ASGIReceiveCallable", send: "ASGISendCallable"
-) -> None:
+async def asgi_app(scope: Scope, receive: ASGIReceiveCallable, send: ASGISendCallable) -> None:
     pass  # pragma: nocover
 
 
@@ -56,65 +58,44 @@ def wsgi_app(environ: Environ, start_response: StartResponse) -> None:
     "app, expected_should_reload",
     [(asgi_app, False), ("tests.test_config:asgi_app", True)],
 )
-def test_config_should_reload_is_set(
-    app: "ASGIApplication", expected_should_reload: bool
-) -> None:
+def test_config_should_reload_is_set(app: ASGIApplication, expected_should_reload: bool) -> None:
     config = Config(app=app, reload=True)
     assert config.reload is True
     assert config.should_reload is expected_should_reload
 
 
-def test_should_warn_on_invalid_reload_configuration(
-    tmp_path: Path, caplog: pytest.LogCaptureFixture
-) -> None:
+def test_should_warn_on_invalid_reload_configuration(tmp_path: Path, caplog: pytest.LogCaptureFixture) -> None:
     config_class = Config(app=asgi_app, reload_dirs=[str(tmp_path)])
     assert not config_class.should_reload
     assert len(caplog.records) == 1
     assert (
-        caplog.records[-1].message
-        == "Current configuration will not reload as not all conditions are met, "
+        caplog.records[-1].message == "Current configuration will not reload as not all conditions are met, "
         "please refer to documentation."
     )
 
-    config_no_reload = Config(
-        app="tests.test_config:asgi_app", reload_dirs=[str(tmp_path)]
-    )
+    config_no_reload = Config(app="tests.test_config:asgi_app", reload_dirs=[str(tmp_path)])
     assert not config_no_reload.should_reload
     assert len(caplog.records) == 2
     assert (
-        caplog.records[-1].message
-        == "Current configuration will not reload as not all conditions are met, "
+        caplog.records[-1].message == "Current configuration will not reload as not all conditions are met, "
         "please refer to documentation."
     )
 
 
-def test_reload_dir_is_set(
-    reload_directory_structure: Path, caplog: pytest.LogCaptureFixture
-) -> None:
+def test_reload_dir_is_set(reload_directory_structure: Path, caplog: pytest.LogCaptureFixture) -> None:
     app_dir = reload_directory_structure / "app"
     with caplog.at_level(logging.INFO):
-        config = Config(
-            app="tests.test_config:asgi_app", reload=True, reload_dirs=[str(app_dir)]
-        )
+        config = Config(app="tests.test_config:asgi_app", reload=True, reload_dirs=[str(app_dir)])
         assert len(caplog.records) == 1
-        assert (
-            caplog.records[-1].message
-            == f"Will watch for changes in these directories: {[str(app_dir)]}"
-        )
+        assert caplog.records[-1].message == f"Will watch for changes in these directories: {[str(app_dir)]}"
         assert config.reload_dirs == [app_dir]
-        config = Config(
-            app="tests.test_config:asgi_app", reload=True, reload_dirs=str(app_dir)
-        )
+        config = Config(app="tests.test_config:asgi_app", reload=True, reload_dirs=str(app_dir))
         assert config.reload_dirs == [app_dir]
 
 
-def test_non_existant_reload_dir_is_not_set(
-    reload_directory_structure: Path, caplog: pytest.LogCaptureFixture
-) -> None:
+def test_non_existant_reload_dir_is_not_set(reload_directory_structure: Path, caplog: pytest.LogCaptureFixture) -> None:
     with as_cwd(reload_directory_structure), caplog.at_level(logging.WARNING):
-        config = Config(
-            app="tests.test_config:asgi_app", reload=True, reload_dirs=["reload"]
-        )
+        config = Config(app="tests.test_config:asgi_app", reload=True, reload_dirs=["reload"])
         assert config.reload_dirs == [reload_directory_structure]
         assert (
             caplog.records[-1].message
@@ -129,9 +110,7 @@ def test_reload_subdir_removal(reload_directory_structure: Path) -> None:
     reload_dirs = [str(reload_directory_structure), "app", str(app_dir)]
 
     with as_cwd(reload_directory_structure):
-        config = Config(
-            app="tests.test_config:asgi_app", reload=True, reload_dirs=reload_dirs
-        )
+        config = Config(app="tests.test_config:asgi_app", reload=True, reload_dirs=reload_dirs)
         assert config.reload_dirs == [reload_directory_structure]
 
 
@@ -188,9 +167,7 @@ def test_reload_excluded_subdirectories_are_removed(
         )
         assert frozenset(config.reload_dirs) == frozenset([reload_directory_structure])
         assert frozenset(config.reload_dirs_excludes) == frozenset([app_dir])
-        assert frozenset(config.reload_excludes) == frozenset(
-            [str(app_dir), str(app_sub_dir)]
-        )
+        assert frozenset(config.reload_excludes) == frozenset([str(app_dir), str(app_sub_dir)])
 
 
 def test_reload_includes_exclude_dir_patterns_are_matched(
@@ -209,13 +186,10 @@ def test_reload_includes_exclude_dir_patterns_are_matched(
             )
             assert len(caplog.records) == 1
             assert (
-                caplog.records[-1].message
-                == "Will watch for changes in these directories: "
+                caplog.records[-1].message == "Will watch for changes in these directories: "
                 f"{sorted([str(first_app_dir), str(second_app_dir)])}"
             )
-            assert frozenset(config.reload_dirs) == frozenset(
-                [first_app_dir, second_app_dir]
-            )
+            assert frozenset(config.reload_dirs) == frozenset([first_app_dir, second_app_dir])
             assert config.reload_includes == ["*/src"]
 
 
@@ -247,9 +221,7 @@ def test_app_unimportable_other(caplog: pytest.LogCaptureFixture) -> None:
     with pytest.raises(SystemExit):
         config.load()
     error_messages = [
-        record.message
-        for record in caplog.records
-        if record.name == "uvicorn.error" and record.levelname == "ERROR"
+        record.message for record in caplog.records if record.name == "uvicorn.error" and record.levelname == "ERROR"
     ]
     assert (
         'Error loading ASGI app. Attribute "app" not found in module "tests.test_config".'  # noqa: E501
@@ -258,7 +230,7 @@ def test_app_unimportable_other(caplog: pytest.LogCaptureFixture) -> None:
 
 
 def test_app_factory(caplog: pytest.LogCaptureFixture) -> None:
-    def create_app() -> "ASGIApplication":
+    def create_app() -> ASGIApplication:
         return asgi_app
 
     config = Config(app=create_app, factory=True, proxy_headers=False)
@@ -319,21 +291,15 @@ def test_ssl_config_combined(tls_certificate_key_and_chain_path: str) -> None:
     assert config.is_ssl is True
 
 
-def asgi2_app(scope: "Scope") -> typing.Callable:
-    async def asgi(
-        receive: "ASGIReceiveCallable", send: "ASGISendCallable"
-    ) -> None:  # pragma: nocover
+def asgi2_app(scope: Scope) -> typing.Callable:
+    async def asgi(receive: ASGIReceiveCallable, send: ASGISendCallable) -> None:  # pragma: nocover
         pass
 
     return asgi  # pragma: nocover
 
 
-@pytest.mark.parametrize(
-    "app, expected_interface", [(asgi_app, "3.0"), (asgi2_app, "2.0")]
-)
-def test_asgi_version(
-    app: "ASGIApplication", expected_interface: Literal["2.0", "3.0"]
-) -> None:
+@pytest.mark.parametrize("app, expected_interface", [(asgi_app, "3.0"), (asgi2_app, "2.0")])
+def test_asgi_version(app: ASGIApplication, expected_interface: Literal["2.0", "3.0"]) -> None:
     config = Config(app=app)
     config.load()
     assert config.asgi_version == expected_interface
@@ -350,9 +316,9 @@ def test_asgi_version(
 )
 def test_log_config_default(
     mocked_logging_config_module: MagicMock,
-    use_colors: typing.Optional[bool],
-    expected: typing.Optional[bool],
-    logging_config,
+    use_colors: bool | None,
+    expected: bool | None,
+    logging_config: dict[str, Any],
 ) -> None:
     """
     Test that one can specify the use_colors option when using the default logging
@@ -369,16 +335,14 @@ def test_log_config_default(
 
 def test_log_config_json(
     mocked_logging_config_module: MagicMock,
-    logging_config: dict,
+    logging_config: dict[str, Any],
     json_logging_config: str,
     mocker: MockerFixture,
 ) -> None:
     """
     Test that one can load a json config from disk.
     """
-    mocked_open = mocker.patch(
-        "uvicorn.config.open", mocker.mock_open(read_data=json_logging_config)
-    )
+    mocked_open = mocker.patch("uvicorn.config.open", mocker.mock_open(read_data=json_logging_config))
 
     config = Config(app=asgi_app, log_config="log_config.json")
     config.load()
@@ -390,7 +354,7 @@ def test_log_config_json(
 @pytest.mark.parametrize("config_filename", ["log_config.yml", "log_config.yaml"])
 def test_log_config_yaml(
     mocked_logging_config_module: MagicMock,
-    logging_config: dict,
+    logging_config: dict[str, Any],
     yaml_logging_config: str,
     mocker: MockerFixture,
     config_filename: str,
@@ -398,9 +362,7 @@ def test_log_config_yaml(
     """
     Test that one can load a yaml config from disk.
     """
-    mocked_open = mocker.patch(
-        "uvicorn.config.open", mocker.mock_open(read_data=yaml_logging_config)
-    )
+    mocked_open = mocker.patch("uvicorn.config.open", mocker.mock_open(read_data=yaml_logging_config))
 
     config = Config(app=asgi_app, log_config=config_filename)
     config.load()
@@ -409,16 +371,18 @@ def test_log_config_yaml(
     mocked_logging_config_module.dictConfig.assert_called_once_with(logging_config)
 
 
-def test_log_config_file(mocked_logging_config_module: MagicMock) -> None:
+@pytest.mark.parametrize("config_file", ["log_config.ini", configparser.ConfigParser(), io.StringIO()])
+def test_log_config_file(
+    mocked_logging_config_module: MagicMock,
+    config_file: str | configparser.RawConfigParser | typing.IO[Any],
+) -> None:
     """
     Test that one can load a configparser config from disk.
     """
-    config = Config(app=asgi_app, log_config="log_config")
+    config = Config(app=asgi_app, log_config=config_file)
     config.load()
 
-    mocked_logging_config_module.fileConfig.assert_called_once_with(
-        "log_config", disable_existing_loggers=False
-    )
+    mocked_logging_config_module.fileConfig.assert_called_once_with(config_file, disable_existing_loggers=False)
 
 
 @pytest.fixture(params=[0, 1])
@@ -445,10 +409,7 @@ def test_env_file(
     Test that one can load environment variables using an env file.
     """
     fp = tmp_path / ".env"
-    content = (
-        f"WEB_CONCURRENCY={web_concurrency}\n"
-        f"FORWARDED_ALLOW_IPS={forwarded_allow_ips}\n"
-    )
+    content = f"WEB_CONCURRENCY={web_concurrency}\n" f"FORWARDED_ALLOW_IPS={forwarded_allow_ips}\n"
     fp.write_text(content)
     with caplog.at_level(logging.INFO):
         config = Config(app=asgi_app, env_file=fp)
@@ -488,9 +449,7 @@ def test_config_log_level(log_level: int) -> None:
 
 @pytest.mark.parametrize("log_level", [None, 0, 5, 10, 20, 30, 40, 50])
 @pytest.mark.parametrize("uvicorn_logger_level", [0, 5, 10, 20, 30, 40, 50])
-def test_config_log_effective_level(
-    log_level: Optional[int], uvicorn_logger_level: Optional[int]
-) -> None:
+def test_config_log_effective_level(log_level: int, uvicorn_logger_level: int) -> None:
     default_level = 30
     log_config = {
         "version": 1,
@@ -530,7 +489,7 @@ def test_ws_max_queue() -> None:
 )
 @pytest.mark.skipif(sys.platform == "win32", reason="require unix-like system")
 def test_bind_unix_socket_works_with_reload_or_workers(
-    tmp_path, reload, workers, short_socket_name
+    tmp_path: Path, reload: bool, workers: int, short_socket_name: str
 ):  # pragma: py-win32
     config = Config(app=asgi_app, uds=short_socket_name, reload=reload, workers=workers)
     config.load()
@@ -550,7 +509,7 @@ def test_bind_unix_socket_works_with_reload_or_workers(
     ids=["--reload=True --workers=1", "--reload=False --workers=2"],
 )
 @pytest.mark.skipif(sys.platform == "win32", reason="require unix-like system")
-def test_bind_fd_works_with_reload_or_workers(reload, workers):  # pragma: py-win32
+def test_bind_fd_works_with_reload_or_workers(reload: bool, workers: int):  # pragma: py-win32
     fdsock = socket.socket(socket.AF_UNIX, socket.SOCK_STREAM)
     fd = fdsock.fileno()
     config = Config(app=asgi_app, fd=fd, reload=reload, workers=workers)
@@ -576,7 +535,7 @@ def test_bind_fd_works_with_reload_or_workers(reload, workers):  # pragma: py-wi
         "--reload=False --workers=1",
     ],
 )
-def test_config_use_subprocess(reload, workers, expected):
+def test_config_use_subprocess(reload: bool, workers: int, expected: bool):
     config = Config(app=asgi_app, reload=reload, workers=workers)
     config.load()
     assert config.use_subprocess == expected
@@ -585,7 +544,4 @@ def test_config_use_subprocess(reload, workers, expected):
 def test_warn_when_using_reload_and_workers(caplog: pytest.LogCaptureFixture) -> None:
     Config(app=asgi_app, reload=True, workers=2)
     assert len(caplog.records) == 1
-    assert (
-        '"workers" flag is ignored when reloading is enabled.'
-        in caplog.records[0].message
-    )
+    assert '"workers" flag is ignored when reloading is enabled.' in caplog.records[0].message
