@@ -2,6 +2,7 @@ from __future__ import annotations
 
 import asyncio
 import os
+import signal
 from collections.abc import AsyncIterator
 from contextlib import asynccontextmanager, contextmanager
 from pathlib import Path
@@ -22,6 +23,18 @@ async def run_server(config: Config, sockets: list[socket] | None = None) -> Asy
         task.cancel()
 
 
+@contextmanager
+def assert_signal(sig: signal.Signals):
+    """Check that a signal was received and handled in a block"""
+    seen: set[int] = set()
+    prev_handler = signal.signal(sig, lambda num, frame: seen.add(num))
+    try:
+        yield
+        assert sig in seen, f"process signal {signal.Signals(sig)!r} was not received or handled"
+    finally:
+        signal.signal(sig, prev_handler)
+
+
 @contextmanager
 def as_cwd(path: Path):
     """Changes working directory and returns to previous on exit."""
