@@ -1,10 +1,15 @@
+from __future__ import annotations
+
+import asyncio
+
+AutoHTTPProtocol: type[asyncio.Protocol]
 try:
-    import httptools
-except ImportError as exc:  # pragma: no cover
+    import httptools  # noqa
+except ImportError:  # pragma: no cover
     from uvicorn.protocols.http.h11_impl import H11Protocol
 
     AutoHTTPProtocol = H11Protocol
-else:
+else:  # pragma: no cover
     from uvicorn.protocols.http.httptools_impl import HttpToolsProtocol
 
     AutoHTTPProtocol = HttpToolsProtocol
