@@ -3,27 +3,21 @@ from __future__ import annotations
 import asyncio
 import http
 import logging
-from typing import (
-    Any,
-    List,
-    Literal,
-    Optional,
-    Sequence,
-    Tuple,
-    Union,
-    cast,
-)
+from typing import Any, Literal, Optional, Sequence, cast
 from urllib.parse import unquote
 
 import websockets
+import websockets.legacy.handshake
 from websockets.datastructures import Headers
 from websockets.exceptions import ConnectionClosed
+from websockets.extensions.base import ServerExtensionFactory
 from websockets.extensions.permessage_deflate import ServerPerMessageDeflateFactory
 from websockets.legacy.server import HTTPResponse
 from websockets.server import WebSocketServerProtocol
 from websockets.typing import Subprotocol
 
 from uvicorn._types import (
+    ASGI3Application,
     ASGISendEvent,
     WebSocketAcceptEvent,
     WebSocketCloseEvent,
@@ -61,7 +55,8 @@ class Server:
 
 
 class WebSocketProtocol(WebSocketServerProtocol):
-    extra_headers: List[Tuple[str, str]]
+    extra_headers: list[tuple[str, str]]
+    logger: logging.Logger | logging.LoggerAdapter[Any]
 
     def __init__(
         self,
@@ -74,7 +69,7 @@ class WebSocketProtocol(WebSocketServerProtocol):
             config.load()
 
         self.config = config
-        self.app = config.loaded_app
+        self.app = cast(ASGI3Application, config.loaded_app)
         self.loop = _loop or asyncio.get_event_loop()
         self.root_path = config.root_path
         self.app_state = app_state
@@ -101,7 +96,7 @@ class WebSocketProtocol(WebSocketServerProtocol):
 
         self.ws_server: Server = Server()  # type: ignore[assignment]
 
-        extensions = []
+        extensions: list[ServerExtensionFactory] = []
         if self.config.ws_per_message_deflate:
             extensions.append(ServerPerMessageDeflateFactory())
 
@@ -117,8 +112,7 @@ class WebSocketProtocol(WebSocketServerProtocol):
         )
         self.server_header = None
         self.extra_headers = [
-            (name.decode("latin-1"), value.decode("latin-1"))
-            for name, value in server_state.default_headers
+            (name.decode("latin-1"), value.decode("latin-1")) for name, value in server_state.default_headers
         ]
 
     def connection_made(  # type: ignore[override]
@@ -136,16 +130,14 @@ class WebSocketProtocol(WebSocketServerProtocol):
 
         super().connection_made(transport)
 
-    def connection_lost(self, exc: Optional[Exception]) -> None:
+    def connection_lost(self, exc: Exception | None) -> None:
         self.connections.remove(self)
 
         if self.logger.isEnabledFor(TRACE_LOG_LEVEL):
             prefix = "%s:%d - " % self.client if self.client else ""
             self.logger.log(TRACE_LOG_LEVEL, "%sWebSocket connection lost", prefix)
 
-        self.lost_connection_before_handshake = (
-            not self.handshake_completed_event.is_set()
-        )
+        self.lost_connection_before_handshake = not self.handshake_completed_event.is_set()
         self.handshake_completed_event.set()
         super().connection_lost(exc)
         if exc is None:
@@ -159,12 +151,10 @@ class WebSocketProtocol(WebSocketServerProtocol):
             self.send_500_response()
         self.transport.close()
 
-    def on_task_complete(self, task: asyncio.Task) -> None:
+    def on_task_complete(self, task: asyncio.Task[None]) -> None:
         self.tasks.discard(task)
 
-    async def process_request(
-        self, path: str, headers: Headers
-    ) -> Optional[HTTPResponse]:
+    async def process_request(self, path: str, request_headers: Headers) -> HTTPResponse | None:
         """
         This hook is called to determine if the websocket should return
         an HTTP response and close.
@@ -175,15 +165,15 @@ class WebSocketProtocol(WebSocketServerProtocol):
         """
         path_portion, _, query_string = path.partition("?")
 
-        websockets.legacy.handshake.check_request(headers)
+        websockets.legacy.handshake.check_request(request_headers)
 
-        subprotocols = []
-        for header in headers.get_all("Sec-WebSocket-Protocol"):
+        subprotocols: list[str] = []
+        for header in request_headers.get_all("Sec-WebSocket-Protocol"):
             subprotocols.extend([token.strip() for token in header.split(",")])
 
         asgi_headers = [
             (name.encode("ascii"), value.encode("ascii", errors="surrogateescape"))
-            for name, value in headers.raw_items()
+            for name, value in request_headers.raw_items()
         ]
         path = unquote(path_portion)
         full_path = self.root_path + path
@@ -212,8 +202,8 @@ class WebSocketProtocol(WebSocketServerProtocol):
         return self.initial_response
 
     def process_subprotocol(
-        self, headers: Headers, available_subprotocols: Optional[Sequence[Subprotocol]]
-    ) -> Optional[Subprotocol]:
+        self, headers: Headers, available_subprotocols: Sequence[Subprotocol] | None
+    ) -> Subprotocol | None:
         """
         We override the standard 'process_subprotocol' behavior here so that
         we return whatever subprotocol is sent in the 'accept' message.
@@ -223,8 +213,7 @@ class WebSocketProtocol(WebSocketServerProtocol):
     def send_500_response(self) -> None:
         msg = b"Internal Server Error"
         content = [
-            b"HTTP/1.1 500 Internal Server Error\r\n"
-            b"content-type: text/plain; charset=utf-8\r\n",
+            b"HTTP/1.1 500 Internal Server Error\r\n" b"content-type: text/plain; charset=utf-8\r\n",
             b"content-length: " + str(len(msg)).encode("ascii") + b"\r\n",
             b"connection: close\r\n",
             b"\r\n",
@@ -235,9 +224,7 @@ class WebSocketProtocol(WebSocketServerProtocol):
         # itself (see https://github.com/encode/uvicorn/issues/920)
         self.handshake_started_event.set()
 
-    async def ws_handler(  # type: ignore[override]
-        self, protocol: WebSocketServerProtocol, path: str
-    ) -> Any:
+    async def ws_handler(self, protocol: WebSocketServerProtocol, path: str) -> Any:  # type: ignore[override]
         """
         This is the main handler function for the 'websockets' implementation
         to call into. We just wait for close then return, and instead allow
@@ -252,14 +239,13 @@ class WebSocketProtocol(WebSocketServerProtocol):
         termination states.
         """
         try:
-            result = await self.app(self.scope, self.asgi_receive, self.asgi_send)
-        except ClientDisconnected:
+            result = await self.app(self.scope, self.asgi_receive, self.asgi_send)  # type: ignore[func-returns-value]
+        except ClientDisconnected:  # pragma: full coverage
             self.closed_event.set()
             self.transport.close()
-        except BaseException as exc:
+        except BaseException:
             self.closed_event.set()
-            msg = "Exception in ASGI application\n"
-            self.logger.error(msg, exc_info=exc)
+            self.logger.exception("Exception in ASGI application\n")
             if not self.handshake_started_event.is_set():
                 self.send_500_response()
             else:
@@ -268,17 +254,15 @@ class WebSocketProtocol(WebSocketServerProtocol):
         else:
             self.closed_event.set()
             if not self.handshake_started_event.is_set():
-                msg = "ASGI callable returned without sending handshake."
-                self.logger.error(msg)
+                self.logger.error("ASGI callable returned without sending handshake.")
                 self.send_500_response()
                 self.transport.close()
             elif result is not None:
-                msg = "ASGI callable should return None, but returned '%s'."
-                self.logger.error(msg, result)
+                self.logger.error("ASGI callable should return None, but returned '%s'.", result)
                 await self.handshake_completed_event.wait()
                 self.transport.close()
 
-    async def asgi_send(self, message: "ASGISendEvent") -> None:
+    async def asgi_send(self, message: ASGISendEvent) -> None:
         message_type = message["type"]
 
         if not self.handshake_started_event.is_set():
@@ -290,9 +274,7 @@ class WebSocketProtocol(WebSocketServerProtocol):
                     get_path_with_query_string(self.scope),
                 )
                 self.initial_response = None
-                self.accepted_subprotocol = cast(
-                    Optional[Subprotocol], message.get("subprotocol")
-                )
+                self.accepted_subprotocol = cast(Optional[Subprotocol], message.get("subprotocol"))
                 if "headers" in message:
                     self.extra_headers.extend(
                         # ASGI spec requires bytes
@@ -324,8 +306,7 @@ class WebSocketProtocol(WebSocketServerProtocol):
                 # websockets requires the status to be an enum. look it up.
                 status = http.HTTPStatus(message["status"])
                 headers = [
-                    (name.decode("latin-1"), value.decode("latin-1"))
-                    for name, value in message.get("headers", [])
+                    (name.decode("latin-1"), value.decode("latin-1")) for name, value in message.get("headers", [])
                 ]
                 self.initial_response = (status, headers, b"")
                 self.handshake_started_event.set()
@@ -356,10 +337,7 @@ class WebSocketProtocol(WebSocketServerProtocol):
                     self.closed_event.set()
 
                 else:
-                    msg = (
-                        "Expected ASGI message 'websocket.send' or 'websocket.close',"
-                        " but got '%s'."
-                    )
+                    msg = "Expected ASGI message 'websocket.send' or 'websocket.close'," " but got '%s'."
                     raise RuntimeError(msg % message_type)
             except ConnectionClosed as exc:
                 raise ClientDisconnected from exc
@@ -372,24 +350,14 @@ class WebSocketProtocol(WebSocketServerProtocol):
                 if not message.get("more_body", False):
                     self.closed_event.set()
             else:
-                msg = (
-                    "Expected ASGI message 'websocket.http.response.body' "
-                    "but got '%s'."
-                )
+                msg = "Expected ASGI message 'websocket.http.response.body' " "but got '%s'."
                 raise RuntimeError(msg % message_type)
 
         else:
-            msg = (
-                "Unexpected ASGI message '%s', after sending 'websocket.close' "
-                "or response already completed."
-            )
+            msg = "Unexpected ASGI message '%s', after sending 'websocket.close' " "or response already completed."
             raise RuntimeError(msg % message_type)
 
-    async def asgi_receive(
-        self,
-    ) -> Union[
-        "WebSocketDisconnectEvent", "WebSocketConnectEvent", "WebSocketReceiveEvent"
-    ]:
+    async def asgi_receive(self) -> WebSocketDisconnectEvent | WebSocketConnectEvent | WebSocketReceiveEvent:
         if not self.connect_sent:
             self.connect_sent = True
             return {"type": "websocket.connect"}
@@ -406,11 +374,11 @@ class WebSocketProtocol(WebSocketServerProtocol):
 
         try:
             data = await self.recv()
-        except ConnectionClosed as exc:
+        except ConnectionClosed:
             self.closed_event.set()
             if self.ws_server.closing:
                 return {"type": "websocket.disconnect", "code": 1012}
-            return {"type": "websocket.disconnect", "code": exc.code}
+            return {"type": "websocket.disconnect", "code": self.close_code or 1005, "reason": self.close_reason}
 
         if isinstance(data, str):
             return {"type": "websocket.receive", "text": data}
